# -*- coding: utf-8 -*-
##############################################################################
#
# Copyright (c) 2004 Bjorn Tillenius
#
# This file is part of Grammatista.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################
"""Imports German into the database.

Usage: german.py [-t]

If -t is specified some sample words are added. Used for testing.
"""

import sys

import grammatista

def main(args=sys.argv[1:], stdout=sys.stdout, stderr=sys.stderr):
    gram = grammatista.Grammatista()
    ## LANGUAGE ##
    print "Adding the language...",
    lang = gram.addLanguage(u"Deutsch")
    print "done."

    ## INFLECTION FORM GROUPS ##
    print "Adding the inflection form groups...",
    case = lang.addInflectionFormGroup('Kasus', ['Nominativ',
                                                'Akkusativ',
                                                'Dativ',
                                                'Genitiv'])
    numeral = lang.addInflectionFormGroup('Numerus', ['Singular', 'Plural'])
    base = lang.addInflectionFormGroup('Bas', ['Bas'])
    gender = lang.addInflectionFormGroup('Geschlecht', ['Maskulinum',
                                                        'Femininum',
                                                        'Neutrum'])
    defineness = lang.addInflectionFormGroup('Bestimmtheit', ['Bestimmt',
                                                              'Unbestimmt'])

    print "done."

    ## WORD CATEGORIES ##
    print "Adding the word categories...",
    noun = lang.addWordCategory('Substantiv')
    noun.addInflectionForms([base, numeral])
    noun.addInflectionForms([case, numeral, defineness])
    noun.addMorphPropertyGroup(gender)
    print "done."


    ## INFLECTIONS ##

    print "Adding the inflections...",
    masculine = gender['Maskulinum']
    feminine = gender['Femininum']
    neutrum = gender['Neutrum']
    base_sing = noun.getInflectionForm('Bas', 'Singular')
    base_plur = noun.getInflectionForm('Bas', 'Plural')

    noun.addInflections(
        (masculine,), base_sing, ('(.*)$',),
        (noun.getInflectionForms('Nominativ', 'Singular', 'Bestimmt'),
         ur'der \1'),
        (noun.getInflectionForms('Akkusativ', 'Singular', 'Bestimmt'),
         ur'den \1'),
        (noun.getInflectionForms('Dativ', 'Singular', 'Bestimmt'),
         ur'dem \1'),
        (noun.getInflectionForms('Genitiv', 'Singular', 'Bestimmt'),
         ur'des \1es'),
        (noun.getInflectionForms('Nominativ', 'Singular', 'Unbestimmt'),
         ur'ein \1'),
        (noun.getInflectionForms('Akkusativ', 'Singular', 'Unbestimmt'),
         ur'einen \1'),
        (noun.getInflectionForms('Dativ', 'Singular', 'Unbestimmt'),
         ur'einem \1'),
        (noun.getInflectionForms('Genitiv', 'Singular', 'Unbestimmt'),
         ur'eines \1es'))

    noun.addInflections(
        (masculine, feminine, neutrum), base_plur, ('(.*)$',),
        (noun.getInflectionForms('Nominativ', 'Plural', 'Bestimmt'),
         ur'die \1'),
        (noun.getInflectionForms('Akkusativ', 'Plural', 'Bestimmt'),
         ur'die \1'),
        (noun.getInflectionForms('Dativ', 'Plural', 'Bestimmt'),
         ur'den \1n'),
        (noun.getInflectionForms('Genitiv', 'Plural', 'Bestimmt'),
         ur'der \1'),
        (noun.getInflectionForms('Nominativ', 'Plural', 'Unbestimmt'),
         ur'\1'),
        (noun.getInflectionForms('Akkusativ', 'Plural', 'Unbestimmt'),
         ur'\1'),
        (noun.getInflectionForms('Dativ', 'Plural', 'Unbestimmt'),
         ur'\1'),
        (noun.getInflectionForms('Genitiv', 'Plural', 'Unbestimmt'),
         ur'\1'))
    
    noun.addInflections(
        (feminine,), base_sing, ('(.*)$',),
        (noun.getInflectionForms('Nominativ', 'Singular', 'Bestimmt'),
         ur'die \1'),
        (noun.getInflectionForms('Akkusativ', 'Singular', 'Bestimmt'),
         ur'die \1'),
        (noun.getInflectionForms('Dativ', 'Singular', 'Bestimmt'),
         ur'der \1'),
        (noun.getInflectionForms('Genitiv', 'Singular', 'Bestimmt'),
         ur'der \1'),
        (noun.getInflectionForms('Nominativ', 'Singular', 'Unbestimmt'),
         ur'eine \1'),
        (noun.getInflectionForms('Akkusativ', 'Singular', 'Unbestimmt'),
         ur'eine \1'),
        (noun.getInflectionForms('Dativ', 'Singular', 'Unbestimmt'),
         ur'einer \1'),
        (noun.getInflectionForms('Genitiv', 'Singular', 'Unbestimmt'),
         ur'einer \1'))
    
    noun.addInflections(
        (neutrum,), base_sing, ('(.*)$',),
        (noun.getInflectionForms('Nominativ', 'Singular', 'Bestimmt'),
         ur'das \1'),
        (noun.getInflectionForms('Akkusativ', 'Singular', 'Bestimmt'),
         ur'das \1'),
        (noun.getInflectionForms('Dativ', 'Singular', 'Bestimmt'),
         ur'dem \1'),
        (noun.getInflectionForms('Genitiv', 'Singular', 'Bestimmt'),
         ur'des \1es'),
        (noun.getInflectionForms('Nominativ', 'Singular', 'Unbestimmt'),
         ur'ein \1'),
        (noun.getInflectionForms('Akkusativ', 'Singular', 'Unbestimmt'),
         ur'ein \1'),
        (noun.getInflectionForms('Dativ', 'Singular', 'Unbestimmt'),
         ur'einem \1'),
        (noun.getInflectionForms('Genitiv', 'Singular', 'Unbestimmt'),
         ur'eines \1es'))

    print "Done."

    if '-t' in args:
        print "Adding some sample words...",
        haus = noun.addWord(u'Haus', neutrum)
        haus[base_plur] = u'Häuser'
        meinung = noun.addWord(u'Meinung', feminine)
        meinung[base_plur] = u'Meinungen'
        apfel = noun.addWord(u'Apfel', masculine)
        apfel[base_plur] = u'Äpfel'
        print "Done."

        print "Adding some exercise definitions...",
        all_forms  = noun.addExerciseDefinition(
            'All Forms', noun.inflectionForms)
        noun.addExerciseDefinition('Only Nominative',
                                   noun.getInflectionForms('Nominativ'))
        only_plural = noun.addExerciseDefinition(
            'Only Plural', noun.getInflectionForms('Plural'))
        noun.addQuizDefinition('All Forms', all_forms, 5) 
    
if __name__ == "__main__":
    sys.exit(main())
