# -*- coding: utf-8 -*-
##############################################################################
#
# Copyright (c) 2004 Bjorn Tillenius
#
# This file is part of Grammatista.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################
"""Imports a language used for performance testing into the database.

Usage: test_language.py
"""

import sys

import grammatista

def main(args=sys.argv[1:], stdout=sys.stdout, stderr=sys.stderr):
    gram = grammatista.Grammatista()
    ## LANGUAGE ##
    lang = gram.addLanguage(u"Test Language");

    ## INFLECTION FORM GROUPS ##
    numeral = lang.addInflectionFormGroup('Numeral', ['Singular', 'Plural'])
    person = lang.addInflectionFormGroup('Person', ['1st', '2nd', '3rd'])
    tense = lang.addInflectionFormGroup('Tense', ['Present',
                                                  'Past',
                                                  'Repetetive Past',
                                                  'Future',
                                                  'Indicative',
                                                  'Imperative'])
    infinitive_group = lang.addInflectionFormGroup('Infinitive Group',
                                                   ['Infinitive'])
    group = lang.addInflectionFormGroup('Group', ['I', 'II', 'III'])

    ## WORD CATEGORIES ##
    verb = lang.addWordCategory('Verb')
    verb.addInflectionForms([infinitive_group])
    verb.addInflectionForms([person, numeral, tense])
    verb.addMorphPropertyGroup(group)


    ## INFLECTIONS ##

    #Present
    verb.addInflections(
        (group['I'],), verb.getInflectionForm('3rd', 'Singular', 'Present'),
        ('(.*[^i])a$',),
        (verb.getInflectionForms('1st', 'Singular', 'Present'), ur'\1u'),
        (verb.getInflectionForms('1st', 'Plural', 'Present'), ur'\1ame'),
        (verb.getInflectionForms('2nd', 'Singular', 'Present'), ur'\1i'),
        (verb.getInflectionForms('2nd', 'Plural', 'Present'), ur'\1ate'))
    
    verb.addInflections(
        (group['I'],), verb.getInflectionForm('3rd', 'Singular', 'Present'),
        ('(.*i)a$',),
        (verb.getInflectionForms('1st', 'Singular', 'Present'), ur'\1u'),
        (verb.getInflectionForms('1st', 'Plural', 'Present'), ur'\1ame'),
        (verb.getInflectionForms('2nd', 'Singular', 'Present'), ur'\1'),
        (verb.getInflectionForms('2nd', 'Plural', 'Present'), ur'\1ate'))
    
    verb.addInflections(
        (group['II'],), verb.getInflectionForm('3rd', 'Singular', 'Present'),
        ('(.*)i$',),
        (verb.getInflectionForms('1st', 'Singular', 'Present'), ur'\1iu'),
        (verb.getInflectionForms('1st', 'Plural', 'Present'), ur'\1ime'),
        (verb.getInflectionForms('2nd', 'Singular', 'Present'), ur'\1i'),
        (verb.getInflectionForms('2nd', 'Plural', 'Present'), ur'\1ite'))
    
    verb.addInflections(
        (group['III'],), verb.getInflectionForm('3rd', 'Singular', 'Present'),
        ('(.*)o$',),
        (verb.getInflectionForms('1st', 'Singular', 'Present'), ur'\1au'),
        (verb.getInflectionForms('1st', 'Plural', 'Present'), ur'\1ome'),
        (verb.getInflectionForms('2nd', 'Singular', 'Present'), ur'\1ai'),
        (verb.getInflectionForms('2nd', 'Plural', 'Present'), ur'\1ote'))
    
    #Past
    verb.addInflections(
        (group['I'], group['II']),
        verb.getInflectionForm('3rd', 'Singular', 'Past'),
        ('(.*)o$',),
        (verb.getInflectionForms('1st', 'Singular', 'Past'), ur'\1au'),
        (verb.getInflectionForms('1st', 'Plural', 'Past'), ur'\1ome'),
        (verb.getInflectionForms('2nd', 'Singular', 'Past'), ur'\1ai'),
        (verb.getInflectionForms('2nd', 'Plural', 'Past'), ur'\1ote'))
    
    verb.addInflections(
        (group['I'], group['II'], group['III']),
        verb.getInflectionForm('3rd', 'Singular', 'Past'),
        (u'(.*)ė$',),
        (verb.getInflectionForms('1st', 'Singular', 'Past'), ur'\1iau'),
        (verb.getInflectionForms('1st', 'Plural', 'Past'), ur'\1ėme'),
        (verb.getInflectionForms('2nd', 'Singular', 'Past'), ur'\1ei'),
        (verb.getInflectionForms('2nd', 'Plural', 'Past'), ur'\1ėte'))
    
    # Repetetive Past
    verb.addInflections(
        (group['I'], group['II'], group['III']),
        verb.getInflectionForm('Infinitive'),
        ('(.*)ti$',),
        (verb.getInflectionForms('1st', 'Singular', 'Repetetive Past'),
                                 ur'\1davau'),
        (verb.getInflectionForms('1st', 'Plural', 'Repetetive Past'),
                                 ur'\1davome'),
        (verb.getInflectionForms('2nd', 'Singular', 'Repetetive Past'),
                                 ur'\1davai'),
        (verb.getInflectionForms('2nd', 'Plural', 'Repetetive Past'),
                                 ur'\1davote'),
        (verb.getInflectionForms('3rd', 'Singular', 'Repetetive Past'),
                                 ur'\1davo'))

    # Future
    verb.addInflections(
        (group['I'], group['II'], group['III']),
        verb.getInflectionForm('Infinitive'),
        ('(.*)ti$',),
        (verb.getInflectionForms('1st', 'Singular', 'Future'), ur'\1siu'),
        (verb.getInflectionForms('1st', 'Plural', 'Future'), ur'\1sime'),
        (verb.getInflectionForms('2nd', 'Singular', 'Future'), ur'\1si'),
        (verb.getInflectionForms('2nd', 'Plural', 'Future'), ur'\1site'),
        (verb.getInflectionForms('3rd', 'Singular', 'Future'), ur'\1s'))
    
    # Indicative
    verb.addInflections(
        (group['I'], group['II'], group['III']),
        verb.getInflectionForm('Infinitive'),
        ('(.*)ti$',),
        (verb.getInflectionForms('1st', 'Singular', 'Indicative'), ur'\1čiau'),
        (verb.getInflectionForms('1st', 'Plural', 'Indicative'), ur'\1tume'),
        (verb.getInflectionForms('2nd', 'Singular', 'Indicative'), ur'\1tum'),
        (verb.getInflectionForms('2nd', 'Plural', 'Indicative'), ur'\1tumete'),
        (verb.getInflectionForms('3rd', 'Singular', 'Indicative'), ur'\1tų'))

    # Imperative
    verb.addInflections(
        (group['I'], group['II'], group['III']),
        verb.getInflectionForm('Infinitive'),
        ('(.*)ti$',),
        (verb.getInflectionForms('1st', 'Singular', 'Imperative'), ur'-'),
        (verb.getInflectionForms('1st', 'Plural', 'Imperative'), ur'\1kime'),
        (verb.getInflectionForms('2nd', 'Singular', 'Imperative'), ur'\1k'),
        (verb.getInflectionForms('2nd', 'Plural', 'Imperative'), ur'\1kite'),
        (verb.getInflectionForms('3rd', 'Singular', 'Imperative'), ur'\1'))

    # 3rd person plural is always the same as 3rd person singular
    for tense_name in ['Present', 'Past', 'Repetetive Past', 'Future',
                       'Indicative', 'Imperative']:
        
        verb.addInflection(
            morphProperties=(group['I'], group['II'], group['III']),
            inputForm=verb.getInflectionForm('3rd', 'Singular', tense_name),
            inputRegExps=('(.*)',),
            outputForms=list(verb.getInflectionForms('3rd', 'Plural',
                                                     tense_name)),
            outputRegExp=r'\1')


    if '-t' in args:

        verb.addExerciseDefinition('All Forms', verb.inflectionForms)
        verb.addExerciseDefinition('Only Inflected Word',
                                   verb.getInflectionForms('3rd', 'Singular',
                                                           'Present'))
        verb.addExerciseDefinition('Only Inflections',
                                   verb.getInflectionForms('1st', 'Singular',
                                                           'Present'))
    
if __name__ == "__main__":
    sys.exit(main())
