##############################################################################
#
# Copyright (c) 2004,2005,2008 Bjorn Tillenius
#
# This file is part of Grammatista.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################
"""The core of grammatista."""

from  zope.interface import implements

from grammatista.language import Language
from grammatista.interfaces import IGrammatista
from grammatista.database.store import get_store


class Grammatista:
    """The main application."""

    implements(IGrammatista)

    @property
    def languages(self):
        """Returns  a list of all defined languages."""
        store = get_store()
        return store.find(Language).order_by('name')

    def get_language(self, string_id):
        """See IGrammatista"""
        store = get_store()
        found_languages = store.find(
            Language,
            Language.string_id == string_id)
        return found_languages.one()

    def add_language(self, string_id, name=None):
        """See IGrammatista"""
        if name is None:
            name = string_id
        language = Language(string_id=string_id, name=name)
        return get_store().add(language)

    def remove_language(self, string_id):
        """See IGrammatista"""
        store = get_store()
        language = store.find(
            Language,
            Language.string_id == string_id)
        language.remove()
