##############################################################################
#
# Copyright (c) 2004,2008 Bjorn Tillenius
#
# This file is part of Grammatista.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################
"""Fields for grammatista objects."""

import re

from zope.interface import implements
from zope.schema import ASCII, Field
from zope.schema.interfaces import ITextLine, SchemaNotProvided

valid_name = re.compile(r"^[a-z0-9][a-z0-9\-]+$")

class Name(ASCII):
    """A named for use in URLs.

    It has to be lower cased, and contain only letters, numbers or
    hyphens. It's not allowed to begin with a hyphen, though.
    """
    def validate(self, value):
        return valid_name.match(value)


class IGrammatistaObject(ITextLine):
    """Marker interface."""


class ExerciseField(Field):

    def _validate(self, value):
        """Check that IExercise is provided."""
        from grammatista.interfaces import IExercise
        Field._validate(self, value)

        if not IExercise.providedBy(value):
            raise SchemaNotProvided


class GrammatistaObject(Field):
    """XXX"""
    implements(IGrammatistaObject)

    _type = unicode

    def get(self, object):
        return getattr(object, self.__name__).label

    def query(self, ob, default=None):
        object = getattr(ob, self.__name__, None)
        if object:
            return object.label
        else:
            return default

    def set(self, ob, value):
        if self.readonly:
            raise TypeError("Can't set values on read-only fields "
                            "(name=%s, class=%s.%s)"
                            % (self.__name__,
                               ob.__class__.__module__,
                               ob.__class__.__name__))
        object = getattr(ob, self.__name__)
        object.label = value


class Language(GrammatistaObject):
    """Language field.

    XXX Good explanation of what this enforces.
    """

class InflectionFormGroup(GrammatistaObject):
    """Inflection Form Group field."""

class WordCategory(GrammatistaObject):
    """Word Category field."""

class InflectionForm(GrammatistaObject):
    """Inflection Form field."""

class Word(GrammatistaObject):
    """Word field."""

class ExerciseDefinition(GrammatistaObject):
    """Exercise definition field."""


class Exercise(GrammatistaObject):
    """Exercise field."""

class QuizDefinition(GrammatistaObject):
    """Exercise definition field."""
