##############################################################################
#
# Copyright (c) 2008 Bjorn Tillenius
#
# This file is part of Grammatista.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################
"""Tests for WordList and related things."""

import unittest

from zope.interface.verify import verifyObject

from grammatista.database.createdb import createDB
from grammatista.interfaces import IWordList
from grammatista.testing.factory import ObjectFactory


class TestWordList(unittest.TestCase):

    def setUp(self):
        createDB()
        self.factory = ObjectFactory()
        self.word_list = self.factory.make_word_list()

    def test_interface(self):
        # WordList implements IWordList.
        verifyObject(IWordList, self.word_list)

    def test_no_words(self):
        # To begin with, a word list contains no words.
        self.assertEqual(list(self.word_list.words), [])

    def test_add_word(self):
        # add_word() adds a word to the word list.
        word_category = self.factory.make_word_category(
            language=self.word_list.language)
        word = self.factory.make_word(word_category=word_category)
        another_word = self.factory.make_word(word_category=word_category)
        self.word_list.add_word(word)
        self.assertEqual(set(self.word_list.words), set([word]))
        self.word_list.add_word(another_word)
        self.assertEqual(set(self.word_list.words), set([word, another_word]))
